@@ -1,6 +1,6 @@
 !***********************************************************************
 ! ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-! Copyright (C) 1998--2019 Keiichi Ishioka <ishioka@gfd-dennou.org>
+! Copyright (C) 1998--2021 Keiichi Ishioka <ishioka@gfd-dennou.org>
 !
 ! This library is free software; you can redistribute it and/or
 ! modify it under the terms of the GNU Lesser General Public
@@ -24,7 +24,7 @@ SUBROUTINE SYGPRM(JM,JV,JR)
 
   CALL MXGCPU(ICPU)
   
-  IF(ICPU.EQ.0.OR.ICPU.EQ.10.OR.ICPU.EQ.20.OR.ICPU.EQ.30) THEN
+  IF(ICPU.EQ.0.OR.ICPU.EQ.10.OR.ICPU.EQ.20.OR.ICPU.EQ.30.OR.ICPU.EQ.1000) THEN
      JR=JM/2/JV
      DO WHILE(MOD(JR,2).EQ.0.AND.JR*JV.GT.512)
         JR=JR/2
