@@ -1,6 +1,6 @@
 !***********************************************************************
 ! ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-! Copyright (C) 1998--2019 Keiichi Ishioka <ishioka@gfd-dennou.org>
+! Copyright (C) 1998--2021 Keiichi Ishioka <ishioka@gfd-dennou.org>
 !
 ! This library is free software; you can redistribute it and/or
 ! modify it under the terms of the GNU Lesser General Public
@@ -29,7 +29,7 @@ SUBROUTINE SYQRJV(JM,JV)
      ELSE
         JV=JM/2
      END IF
-  ELSE IF(ICPU.EQ.30) THEN ! avx512
+  ELSE IF(ICPU.EQ.30.OR.ICPU.EQ.1000) THEN ! avx512 or fx
      IF(MOD(JM,16).EQ.0) THEN
         JV=8
      ELSE
